'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _utilities = require('./utilities');

exports.default = function (reducers) {
    var reducerKeys = undefined;

    reducerKeys = Object.keys(reducers);

    return function (inputState, action) {
        /* eslint-disable no-process-env */
        if (process.env.NODE_ENV !== 'production') {
            /* eslint-enable no-process-env */
            var warningMessage = undefined;

            warningMessage = (0, _utilities.getUnexpectedInvocationParameterMessage)(inputState, reducers, action);

            if (warningMessage) {
                /* eslint-disable no-console */
                console.error(warningMessage);
                /* eslint-enable no-console */
            }
        }

        return inputState.withMutations(function (temporaryState) {
            reducerKeys.forEach(function (reducerName) {
                var currentDomainState = undefined,
                    nextDomainState = undefined,
                    reducer = undefined;

                reducer = reducers[reducerName];

                currentDomainState = temporaryState.get(reducerName);

                nextDomainState = reducer(currentDomainState, action);

                (0, _utilities.validateNextState)(nextDomainState, reducerName, action);

                temporaryState.set(reducerName, nextDomainState);
            });
        });
    };
}; /* eslint-disable lodash3/prefer-lodash-method */

module.exports = exports['default'];
//# sourceMappingURL=combineReducers.js.map
